bivariate_outliers: Check for bivariate outliers
Description
Checks for bivariate outliers in a data.frame
Usage
bivariate_outliers(x, threshold_r = 10, threshold_b = 1.5)
Value
A data frame with all the observations considered as bivariate outliers
Arguments
- x
A data.frame object
- threshold_r
Threshold for the case of two continuous variables
- threshold_b
Threshold for the case of one continuous and one categorical variable