Calculates different scores to measure how much extreme are the different data points
Usage
xscores(x, type = "z")
Arguments
x
A vector
type
'z' calculates standard normal scores, 'z-out' calculates standard normal scores excluding
each data point when computing the mean and the standard deviation, 't' calculates t scores,
'chisq' calculates chisquared scores, 'tukey' calculates scores based on the boxplot method,
'mad' calculates scores using median and mad instead of mean and sd.